.. _require_supervisor_module:

:mod:`fabtools.require.supervisor`
----------------------------------

.. automodule:: fabtools.require.supervisor
    :members:

    .. seealso:: :ref:`supervisor_module`
